
-- line pattern: any complete line of square is removed ----------------------

function line_delete(y_line)
    local x
    local y
    local width
    local color

    width=u61_get_width()
    x=0
    while x<width do
        u61_blow_up_square(x,y_line)
        x=x+1
    end
end

function line_match_pattern(match_count)
    local x
    local y
    local width
    local height
    local holes
    local lines
    
    width=u61_get_width()
    height=u61_get_height()

    lines=0
    y=0
    while y<height and lines==0 do
        holes=0
        x=0
        while x<width do
            if u61_get_square_color(x,y)<0 then
                holes=holes+1
            end
            if not (u61_is_square_exploding(x,y)==0) then
                holes=holes+1
            end
            x=x+1
        end
        if holes==0 then 
            line_delete(y)
            lines=lines+1
        end
        y=y+1
    end    

    if lines>0 then
        u61_add_score((match_count+1)*10000)    
        if (match_count>=3) then
            u61_add_antidote()
        end
    end

    return lines
end

